@@ -225,7 +225,7 @@ print.estmod<-function(x, digits = getOption("digits"),...){
     lowsup<-x$lowsup
     uppsup<-x$uppsup
     cat("\nBandwidth:", formatC(bw, digits=digits,...))
-    cat("\nSupport where the number of modes are computed\n", formatC(lowsup, digits=digits,...), formatC(uppsup, digits=digits,...))
+    cat("\nSupport where the number of modes is computed\n", formatC(lowsup, digits=digits,...), formatC(uppsup, digits=digits,...))
     cat("\n")
   }
   if(!is.null(x$excess.mass)){
@@ -1884,7 +1884,7 @@ modetest=function(data,mod0=1,method="ACR",B=500,lowsup=-Inf,uppsup=Inf,submetho
     namestatistic="Excess mass"
   }else if (method=="ACR"){
     pval=emcbw(data,mod0,B,submethod,lowsup,uppsup,n,tol,tol2,gridsize)
-    namemethod="Ameijeiras-Alonso et al. (2016) excess mass test"
+    namemethod="Ameijeiras-Alonso et al. (2018) excess mass test"
     namestatistic="Excess mass"
   }
 
